import fs from 'fs';
import path from 'path';

/* eslint no-console: 0 */
function log () {
  var args = [], len = arguments.length;
  while ( len-- ) args[ len ] = arguments[ len ];

  console.log.apply(console, [ '🔌  rollup-plugin-node-direct: ' ].concat( args ))
}


function get_resolved_include (root, subdir, target, verbose) {
  var pkg

  if (path.isAbsolute(subdir)) {
    root = ''
  }
  var pPath = path.join(subdir, target, 'package.json');

  try {
    pkg = JSON.parse(fs.readFileSync(pPath))
    var indicated = pkg['jsnext:main'] || pkg.main || pkg.browser;

    if (typeof indicated === 'string') {
      return path.join(root, subdir, target, indicated);
    }
  } catch (e) { /**/ }

  if (verbose) log('🔴', target, 'not found as', pPath)
}


function nodeResolve ( options ) {
  if ( options === void 0 ) options = {};

  var paths = options.paths;
  var root = options.root || process.cwd();
	var skip = options.skip || [];
  var verbose = options.verbose;
  if (verbose) log('Paths:', options.paths)

	return {
		name: 'node-direct',

		resolveId: function resolveId ( importee, importer ) {
			if (
        !importer || // entry module
        /\0/.test( importee ) ||  // belongs to another plugin
        skip.includes(importee) ||
        importee.endsWith('.js') || // Packages don't end in .js.
        importee.startsWith('.') // Packages aren't relative.
      ) {
        return null;
      }
      if (verbose) log(importer, 'asked for', importee)

			return new Promise( function ( accept /*, reject */ ) {
        for (var i = 0, j = paths.length ; i < j ; ++i) {
          var resolved = get_resolved_include(root, paths[i], importee, verbose);
          if (resolved) {
            if (verbose)
              log('✅', importer, 'asked for', importee, 'and gets', resolved)
            accept( resolved );
            return
          }
        }
        accept( null );
			});
		}
	};
}

export default nodeResolve;